clear all
set more off
cap log close


global rawdata=".../replication/rawdata"
global workdata=".../replication/Workdata"
global output=".../replication/Output"

***********************************
* 1. merge data for main analysis *

********************
* main census data *

use "$rawdata/education gap month.dta", clear
merge 1:1 provcd birthyr birthmo using "$rawdata/census gap year.dta"
drop _merge
merge 1:1 provcd birthyr birthmo using "$rawdata/census gap moving.dta"
drop _merge

g tsize=malec+femalec
keep sexratio sexratio_year sexratio_moving dedum dedum_year dedum_moving provcd birthyr birthmo edum_male edum_female femalec malec tsize tsize_year tsize_moving

save "$rawdata/census_main_clean.dta",replace



use "$rawdata/census_main_clean.dta", clear

merge m:1 provcd using "$rawdata/NBS province death rate.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge

merge m:1 provcd using "$rawdata/cohort_53.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge

merge m:1 provcd using "$rawdata/controls_famine.dta"
tab _merge
drop if _merge==1 
drop if _merge==2
drop _merge

forvalues i=1953/1966{
g pct_edr`i'=0
}
replace pct_edr1958=excess
replace pct_edr1959=excess
replace pct_edr1960=excess
replace pct_edr1961=excess
g faminePX=0
forvalues t=1954/1966{
local j=`t'-1
replace faminePX=(pct_edr`j'*max(9-birthmo,0)+pct_edr`t'*min(9,birthmo))/9 if birthyr==`t'
}


g sex10=(male0+male1+male2+male3+male4+male5+male6+male7+male8+male9+male10)/(female0+female1+female2+female3+female4+female5+female6+female7+female8+female9+female10)
g fsex10=faminePX*sex10
g son=0
replace son=1 if sex10>1.07


g interson=faminePX*son
g famineg=faminePX*medium_gdp
g fhealth=faminePX*medium_health
g fhigh=faminePX*medium_high


g bcd=birthyr*birthmo

replace sexratio=sexratio*100
replace sexratio_year=sexratio_year*100
replace sexratio_moving=sexratio_moving*100

g sex4=(male0+male1+male2+male3)/(female0+female1+female2+female3)
g fsex4=faminePX*sex4
g son4=0
replace son4=1 if sex4>1.05


keep sexratio sexratio_year sexratio_moving dedum dedum_year dedum_moving faminePX interson fsex10 famineg fhealth fhigh tsize tsize_year tsize_moving provcd birthyr birthmo edum_male edum_female bcd excess son medium_gdp medium_health medium_high malec femalec death* pct_edr* famine son4 sex10
 
save "$workdata/census_main_regression.dta",replace



******************
* main CFPS data *


use "$rawdata/cfps_height.dta", clear

merge m:1 provcd using "$rawdata/NBS province death rate.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge
forvalues i=1953/1966{
g pct_edr`i'=0
}
replace pct_edr1958=excess
replace pct_edr1959=excess
replace pct_edr1960=excess
replace pct_edr1961=excess
g faminePX=0
replace faminePX=excess if birthyr>1958 & birthyr<1962

merge m:1 provcd using "$rawdata/cohort_53.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge

g sex10=(male0+male1+male2+male3+male4+male5+male6+male7+male8+male9+male10)/(female0+female1+female2+female3+female4+female5+female6+female7+female8+female9+female10)
g fsex10=faminePX*sex10
g son=0
replace son=1 if sex10>1.07
g interson=faminePX*son



merge m:1 provcd using "$rawdata/controls_famine.dta"
tab _merge
drop if _merge==1 
drop if _merge==2
drop _merge

g famineg=faminePX*dmlgdp
g fhealth=faminePX*dmlhealth
g fhigh=faminePX*dmlhigh

keep gap1 male_hm female_hm faminePX interson famineg fhealth fhigh cs provcd birthyr

save "$workdata/CFPS_main_regression.dta",replace






********************************
* 2. merge data for robustness *

*************************
** CFPS selection data **


use "$rawdata/cfps_family_background_clean.dta",clear

merge m:1 provcd using "$rawdata/NBS province death rate.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge
forvalues i=1953/1966{
g pct_edr`i'=0
}
replace pct_edr1958=excess
replace pct_edr1959=excess
replace pct_edr1960=excess
replace pct_edr1961=excess
g faminePX=0
forvalues t=1954/1966{
local j=`t'-1
replace faminePX=(pct_edr`j'*max(9-qa1m,0)+pct_edr`t'*min(9,qa1m))/9 if qa1y==`t'
}
merge m:1 provcd using "$rawdata/cohort_53.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge

g sex10=(male0+male1+male2+male3+male4+male5+male6+male7+male8+male9+male10)/(female0+female1+female2+female3+female4+female5+female6+female7+female8+female9+female10)
g fsex10=faminePX*sex10
g son=0
replace son=1 if sex10>1.07
g interson=faminePX*son




merge m:1 provcd using "$rawdata/controls_famine.dta"
tab _merge
drop if _merge==1 
drop if _merge==2
drop _merge



g famineg=faminePX*medium_gdp
g fhealth=faminePX*medium_health
g fhigh=faminePX*medium_high
g fgender=faminePX*gender

keep provcd birthyr gender feduy meduy fop mop qb1 sb sg qa302 faminePX famineg fhealth fhigh fgender

save "$workdata/CFPS_robust_family_background.dta",replace


