clear all
set more off
cap log close
set scheme s1color


global rawdata=".../replication/rawdata"
global workdata=".../replication/Workdata"
global output=".../replication/Output"



use "$workdata/census_main_regression.dta", clear
g selective=0
replace selective=1 if birthyr==1959 & birthmo>6
replace selective=1 if birthyr==1960
replace selective=1 if birthyr==1961


*********************************
** Table 2: Cohort Sex Ratios

preserve
est clear

reghdfe sexratio faminePX interson [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est1
reghdfe sexratio faminePX interson famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est2
reghdfe sexratio faminePX interson [aweight=tsize] if selective==0 & birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est3

reghdfe sexratio_year faminePX interson [aweight=tsize_year] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store est4
reghdfe sexratio_year faminePX interson famineg fhealth fhigh [aweight=tsize_year] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store est5

reghdfe sexratio_moving faminePX interson [aweight=tsize_moving] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est6
reghdfe sexratio_moving faminePX interson famineg fhealth fhigh [aweight=tsize_moving] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est7


esttab est* using "$output/Table2_census_sexratio.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson) r2 se

restore



******************************
* Table 4: Gender gap in edu *

preserve
est clear

reghdfe dedum faminePX interson [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est1
reghdfe dedum faminePX interson famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est2
reghdfe dedum faminePX interson [aweight=tsize] if selective==0 & birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est3

reghdfe dedum_year faminePX interson [aweight=tsize_year] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store est4
reghdfe dedum_year faminePX interson famineg fhealth fhigh [aweight=tsize_year] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store est5

reghdfe dedum_moving faminePX interson [aweight=tsize_moving] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est6
reghdfe dedum_moving faminePX interson famineg fhealth fhigh [aweight=tsize_moving] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store est7


esttab est* using "$output/Table4_census_edu_gap.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson) r2 se

restore

**********************************
* Table A8 Panel B: Absolute edu *

preserve
est clear

reghdfe edum_male faminePX interson [aweight=malec] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store edumale1
reghdfe edum_male faminePX interson famineg fhealth fhigh [aweight=malec] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store edumale2

reghdfe edum_female faminePX interson [aweight=femalec] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store edufemale1
reghdfe edum_female faminePX interson famineg fhealth fhigh [aweight=femalec] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store edufemale2


esttab edu* using "$output/TableA8B_edu_absolute.csv", replace b(4) se(4) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson) r2 se

restore


********************************
* Figure 7: Flexible estimates *
preserve
est clear

drop if birthyr<1949
drop if birthyr>1970

tab birthyr,gen(year)

forvalues i=1/22{
local j=`i'+48
g ys19`j'=excess*son*year`i'
g yg19`j'=excess*medium_gdp*year`i'
g yh19`j'=excess*medium_health*year`i'
g ye19`j'=excess*medium_high*year`i'
}

rename ys* y*

reghdfe sexratio y1955 y1956 y1957 y1958 y1959 y1960 y1961 y1962 y1963 y1964 y1965 yg1955 yg1956 yg1957 yg1958 yg1959 yg1960 yg1961 yg1962 yg1963 yg1964 yg1965 yh1955 yh1956 yh1957 yh1958 yh1959 yh1960 yh1961 yh1962 yh1963 yh1964 yh1965 ye1955 ye1956 ye1957 ye1958 ye1959 ye1960 ye1961 ye1962 ye1963 ye1964 ye1965 [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e1

coefplot e1, keep(y1955 y1956 y1957 y1958 y1959 y1960 y1961 y1962 y1963) yline(0, lp(--) lcolor(black)) coeflabels(y1955=1955 y1956=1956 y1957=1957 y1958=1958 y1959=1959 y1960=1960 y1961=1961 y1962=1962 y1963=1963) vertical recast(connect) graphregion(fcolor(white)) legend(off) nooffset ciopts(lp(--) recast(rcap)) ytitle("Estimated coeffcients")

graph export "$output/Figure7A_sex_ratio.png", as(png) name("Graph") width(2400) replace

reghdfe dedum y1955 y1956 y1957 y1958 y1959 y1960 y1961 y1962 y1963 y1964 y1965 yg1955 yg1956 yg1957 yg1958 yg1959 yg1960 yg1961 yg1962 yg1963 yg1964 yg1965 yh1955 yh1956 yh1957 yh1958 yh1959 yh1960 yh1961 yh1962 yh1963 yh1964 yh1965 ye1955 ye1956 ye1957 ye1958 ye1959 ye1960 ye1961 ye1962 ye1963 ye1964 ye1965 [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e2
coefplot e2, keep(y1955 y1956 y1957 y1958 y1959 y1960 y1961 y1962 y1963) yline(0, lp(--) lcolor(black)) coeflabels(y1955=1955 y1956=1956 y1957=1957 y1958=1958 y1959=1959 y1960=1960 y1961=1961 y1962=1962 y1963=1963) vertical recast(connect) graphregion(fcolor(white)) legend(off) nooffset ciopts(lp(--) recast(rcap)) ytitle("Estimated coeffcients")


graph export "$output/Figure7B_edu_gap.png", as(png) name("Graph") width(2400) replace

restore


************************************************
* Figure A2: Flexible estimates with two lines *

preserve
est clear

drop if birthyr<1949
drop if birthyr>1970

tab birthyr,gen(year)

forvalues i=1/22{
local j=`i'+48
g s19`j'=son*year`i'
g g19`j'=medium_gdp*year`i'
g h19`j'=medium_health*year`i'
g e19`j'=medium_high*year`i'
}


reghdfe sexratio s1955 s1956 s1957 s1958 s1959 s1960 s1961 s1962 s1963 s1964 s1965 g1955 g1956 g1957 g1958 g1959 g1960 g1961 g1962 g1963 g1964 g1965 h1955 h1956 h1957 h1958 h1959 h1960 h1961 h1962 h1963 h1964 h1965 e1955 e1956 e1957 e1958 e1959 e1960 e1961 e1962 e1963 e1964 e1965 [aweight=tsize] if birthyr>1951 & birthyr<1967 & excess>7.11, absorb(provcd bcd) cluster(provcd)
est store e1

reghdfe sexratio s1955 s1956 s1957 s1958 s1959 s1960 s1961 s1962 s1963 s1964 s1965 g1955 g1956 g1957 g1958 g1959 g1960 g1961 g1962 g1963 g1964 g1965 h1955 h1956 h1957 h1958 h1959 h1960 h1961 h1962 h1963 h1964 h1965 e1955 e1956 e1957 e1958 e1959 e1960 e1961 e1962 e1963 e1964 e1965 [aweight=tsize] if birthyr>1951 & birthyr<1967 & excess<=7.11, absorb(provcd bcd) cluster(provcd)
est store e2


coefplot (e1, msymbol(t)) (e2, msymbol(s)), keep(s1955 s1956 s1957 s1958 s1959 s1960 s1961 s1962 s1963) coeflabels(s1955=1955 s1956=1956 s1957=1957 s1958=1958 s1959=1959 s1960=1960 s1961=1961 s1962=1962 s1963=1963) yline(0, lp(--) lcolor(black)) vertical recast(connect) graphregion(fcolor(white)) legend(off) nooffset ciopts(lp(--) recast(rcap)) ytitle("Estimated coeffcients")

graph export "$output/FigureA2A_sex_ratio_twolines.png", as(png) name("Graph") width(2400) replace



reghdfe dedum s1955 s1956 s1957 s1958 s1959 s1960 s1961 s1962 s1963 s1964 s1965 g1955 g1956 g1957 g1958 g1959 g1960 g1961 g1962 g1963 g1964 g1965 h1955 h1956 h1957 h1958 h1959 h1960 h1961 h1962 h1963 h1964 h1965 e1955 e1956 e1957 e1958 e1959 e1960 e1961 e1962 e1963 e1964 e1965 [aweight=tsize] if birthyr>1951 & birthyr<1967 & excess>7.11, absorb(provcd bcd) cluster(provcd)
est store e3

reghdfe dedum s1955 s1956 s1957 s1958 s1959 s1960 s1961 s1962 s1963 s1964 s1965 g1955 g1956 g1957 g1958 g1959 g1960 g1961 g1962 g1963 g1964 g1965 h1955 h1956 h1957 h1958 h1959 h1960 h1961 h1962 h1963 h1964 h1965 e1955 e1956 e1957 e1958 e1959 e1960 e1961 e1962 e1963 e1964 e1965 [aweight=tsize] if birthyr>1951 & birthyr<1967 & excess<=7.11, absorb(provcd bcd) cluster(provcd)
est store e4


coefplot (e3, msymbol(t)) (e4, msymbol(s)), keep(s1955 s1956 s1957 s1958 s1959 s1960 s1961 s1962 s1963) coeflabels(s1955=1955 s1956=1956 s1957=1957 s1958=1958 s1959=1959 s1960=1960 s1961=1961 s1962=1962 s1963=1963) yline(0, lp(--) lcolor(black)) vertical recast(connect) graphregion(fcolor(white)) legend(off) nooffset ciopts(lp(--) recast(rcap)) ytitle("Estimated coeffcients")

graph export "$output/FigureA2B_edu_gap_twolines.png", as(png) name("Graph") width(2400) replace

restore

*********************
* Table 7: Placebo *

preserve
est clear

use "$workdata/census_main_regression.dta", clear


forvalues i=1969/1985{
g pct_edr`i'=0
}
replace pct_edr1974=excess
replace pct_edr1973=excess
replace pct_edr1972=excess
replace pct_edr1971=excess
g famine_placebo=0
forvalues t=1970/1980{
local j=`t'-1
replace famine_placebo=(pct_edr`j'*max(9-birthmo,0)+pct_edr`t'*min(9,birthmo))/9 if birthyr==`t'
}




g inter_placebo=famine_placebo*son
g placebo_gdp=famine_placebo*medium_gdp
g placebo_health=famine_placebo*medium_health
g placebo_high=famine_placebo*medium_high




reghdfe sexratio famine_placebo inter_placebo [aweight=tsize] if birthyr>1965 & birthyr<1979, absorb(provcd bcd) cluster(provcd)
est store s5
reghdfe dedum famine_placebo inter_placebo [aweight=tsize] if birthyr>1965 & birthyr<1979, absorb(provcd bcd) cluster(provcd)
est store e5

reghdfe sexratio famine_placebo inter_placebo placebo_gdp placebo_health placebo_high [aweight=tsize] if birthyr>1965 & birthyr<1979, absorb(provcd bcd) cluster(provcd)
est store s6
reghdfe dedum famine_placebo inter_placebo placebo_gdp placebo_health placebo_high [aweight=tsize] if birthyr>1965 & birthyr<1979, absorb(provcd bcd) cluster(provcd)
est store e6



esttab s5 s6 e5 e6 using "$output/Table7_census_placebo.csv", replace b(4) se(4) star(* 0.1 ** 0.05 *** 0.01)  keep(famine_placebo inter_placebo) r2 se
restore






