clear all
set more off
cap log close

global rawdata=".../replication/rawdata"
global workdata=".../replication/Workdata"
global output=".../replication/Output"



use "$workdata/census_main_regression.dta", clear


*************************************************
* Table 5: Different measures of son preference *


preserve
est clear

g interson4=faminePX*son4

g son6=0
replace son6=1 if sex10>1.06

g interson6=faminePX*son6


foreach var in sexratio dedum {

reghdfe `var' faminePX interson4 famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'1

reghdfe `var' faminePX fsex10 famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'2

reghdfe `var' faminePX interson6 famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'3

}
esttab sexratio* dedum* using "$output/Table5A_measures.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson4 fsex10 interson6) r2 se

restore


preserve
est clear

merge m:1 provcd using "$workdata/measures.dta"
drop _merge

g inter_m1=faminePX*last_sexratio

g inter_m2=faminePX*shareb

g inter_m3=faminePX*gender_norm


foreach var in sexratio dedum {

reghdfe `var' faminePX inter_m1 famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'1

reghdfe `var' faminePX inter_m2 famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'2

reghdfe `var' faminePX inter_m3 famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'3

}
esttab sexratio* dedum* using "$output/Table5B_measures.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX inter_m1 inter_m2 inter_m3) r2 se

restore




*****************************************
* Table 6 Panel A: Alternative exposure *

preserve
est clear

g n1=(death1954+death1955+death1956+death1957)/4
g e1=famine-n1
drop pct_edr*

forvalues i=1953/1966{
g pct_edr`i'=0
}
replace pct_edr1958=e1
replace pct_edr1959=e1
replace pct_edr1960=e1
replace pct_edr1961=e1

g famine_another=0
forvalues t=1954/1966{
local j=`t'-1
replace famine_another=(pct_edr`j'*max(9-birthmo,0)+pct_edr`t'*min(9,birthmo))/9 if birthyr==`t'
}


g inter_another=famine_another*son
g another_gdp=famine_another*medium_gdp
g another_health=famine_another*medium_health
g another_high=famine_another*medium_high


reghdfe sexratio famine_another inter_another [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store s9
reghdfe dedum famine_another inter_another [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e9

reghdfe sexratio famine_another inter_another another_gdp another_health another_high [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store s10
reghdfe dedum famine_another inter_another another_gdp another_health another_high [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e10

esttab s9 s10 e9 e10 using "$output/Table6A_alternative_excessrate.csv", replace b(4) se(4) star(* 0.1 ** 0.05 *** 0.01)  keep(famine_another inter_another) r2 se

restore


*****************************************
* Table 6 Panel B: Alternative exposure *

preserve
est clear

g famineAX=0

forvalues t=1954/1966{
local j=`t'-1
replace famineAX=(death`j'*max(9-birthmo,0)+death`t'*min(9,birthmo))/9 if birthyr==`t'
}


g intersonA=famineAX*son
g faminegA=famineAX*medium_gdp
g fhealthA=famineAX*medium_health
g fhighA=famineAX*medium_high




foreach var in sexratio dedum {

reghdfe `var' famineAX intersonA [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'1
reghdfe `var' famineAX intersonA faminegA fhealthA fhighA [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'2
}
esttab sexratio1 sexratio2 dedum1 dedum2 using "$output/Table6B_actual_deathrate.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(famineAX intersonA) r2 se

restore

********************************
* Table A3: Pre-famine controls *

preserve
est clear

merge m:1 provcd using "$rawdata/pre_famine_controls.dta"
tab _merge
drop if _merge==1 
drop if _merge==2
drop _merge




foreach var in healthinstitution doctors gdp revenue expenditure pop {
replace `var'_mean =0 if `var'_mean==.
}

foreach var in healthinstitution doctors gdp revenue expenditure pop {
g c_`var'=faminePX*`var'_mean
}

foreach var in healthinstitution doctors gdp revenue expenditure pop {
g trend_`var'=birthyr*`var'_mean
}



global cntrl_health "c_healthinstitution c_doctors"
global cntrl_economic "c_gdp c_revenue c_expenditure"
global cntrl_infrastructure "c_railways"
global cntrl_all "$cntrl_health $cntrl_economic pop_mean"
global cntrl_trend "trend_healthinstitution trend_doctors trend_gdp trend_revenue trend_expenditure trend_pop "



foreach var in sexratio dedum {

reghdfe `var' faminePX interson famineg fhealth fhigh $cntrl_health [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store `var'1

reghdfe `var' faminePX interson famineg fhealth fhigh $cntrl_economic [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store `var'2

reghdfe `var' faminePX interson famineg fhealth fhigh pop_mean [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store `var'3

reghdfe `var' faminePX interson famineg fhealth fhigh $cntrl_all [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store `var'4

reghdfe `var' faminePX interson famineg fhealth fhigh $cntrl_all $cntrl_trend [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd birthyr) cluster(provcd)
est store `var'5

}
esttab sexratio* dedum* using "$output/TableA3_pre_famine_controls.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01) keep(faminePX interson) r2 se


restore



*************************************
* Table A4: Including other changes *

preserve
est clear

merge m:1 provcd using "$rawdata/Chinese civil war.dta"
drop _merge

replace duration=0 if duration==.
g fwar=faminePX*duration


foreach var in sexratio dedum {

reghdfe `var' faminePX interson fwar [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'1
reghdfe `var' faminePX interson fwar famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'2
}
esttab sexratio1 sexratio2 dedum1 dedum2 using "$output/TableA4A_war.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson fwar) r2 se

merge m:1 provcd using "$rawdata/CR province intensity.dta"
tab _merge
drop if _merge==1
drop if _merge==2
drop _merge

egen ndeath=std(sdeath)

g fcr=faminePX*ndeath


reghdfe sexratio faminePX interson fcr [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store s7
reghdfe dedum faminePX interson fcr [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e7

reghdfe sexratio faminePX interson fcr famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store s8
reghdfe dedum faminePX interson fcr famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e8

esttab s7 s8 e7 e8 using "$output/TableA4B_CR.csv", replace b(4) se(4) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson fcr) r2 se


restore

***************************
* Table A5: Later cohorts *

preserve
est clear

reghdfe sexratio faminePX interson [aweight=tsize] if birthyr>1953 & birthyr<1971, absorb(provcd bcd) cluster(provcd)
est store s1
reghdfe dedum faminePX interson [aweight=tsize] if birthyr>1953 & birthyr<1971, absorb(provcd bcd) cluster(provcd)
est store e1

reghdfe sexratio faminePX interson famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1971, absorb(provcd bcd) cluster(provcd)
est store s2
reghdfe dedum faminePX interson famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1971, absorb(provcd bcd) cluster(provcd)
est store e2


esttab s1 s2 e1 e2 using "$output/TableA5_later_cohorts.csv", replace b(4) se(4) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson) r2 se

restore

*******************************
* Table A6: exposure ages 0-1 *

preserve
est clear

g pct_edr1967=0

g faminePX1=0
forvalues t=1954/1966{
local j=`t'+1
replace faminePX1=(pct_edr`j'*birthmo+pct_edr`t'*(12-birthmo))/12 if birthyr==`t'
}

g interson1=faminePX1*son

g famineg1=faminePX1*medium_gdp
g fhealth1=faminePX1*medium_health
g fhigh1=faminePX1*medium_high


foreach var in sexratio dedum {

reghdfe `var' faminePX interson faminePX1 interson1 [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'1
reghdfe `var' faminePX interson faminePX1 interson1 famineg fhealth fhigh famineg1 fhealth1 fhigh1 [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store `var'2
}

esttab sexratio1 sexratio2 dedum1 dedum2 using "$output/TableA6_exposure_ages01.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson faminePX1 interson1) r2 se
restore


************************************
* Table A7: Controlling for health *

preserve
est clear

merge m:1 provcd birthyr using "$rawdata/cfps_height.dta"
drop if _merge==1
drop if _merge==2
drop _merge

drop if gap1==.

reghdfe dedum faminePX interson famineg fhealth fhigh [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e1
reghdfe dedum faminePX interson famineg fhealth fhigh gap1 [aweight=tsize] if birthyr>1953 & birthyr<1967, absorb(provcd bcd) cluster(provcd)
est store e2

esttab e1 e2 using "$output/TableA7_controlfor_health.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  keep(faminePX interson famineg fhealth fhigh gap1) r2 se

restore


