clear all
set more off
cap log close
set scheme s1color

global rawdata=".../replication/rawdata"
global workdata=".../replication/Workdata"
global output=".../replication/Output"



**************************
* Figure 4: CDF function *

preserve
est clear

clear
set obs 10000

generate x1 = rnormal(0.5,0.17)

sum x1

cumul x1, generate(cdf) 

line cdf x1 if x1>=0,sort xlabel(0(0.1)1) xline(0.15, lp(1) lcolor(red)) xline(0.12, lp(--) lcolor(blue)) xtitle("Quality") ytitle(" CDF of quality") legend(off) graphregion(fcolor(white))


graph export "$output/Figure4_CDF.png", as(png) name("Graph") width(2400) replace

restore


**************************************************
*Figure 6: by famine severity and son preference *

preserve
est clear

use "$workdata/ famine decomposing data.dta",clear

twoway (line hfhs byear,lp(solid) lcolor(black)) (line lfhs byear, lp(dash) lcolor(black)),xtitle("Birth year") ytitle("Cohort sex ratios") xlabel(1949(2)1965) ylabel(0.98(0.02)1.1) xline(1959, lp(dot) lcolor(red)) xline(1961, lp(dot) lcolor(red)) yline(0, lp(--) lcolor(black)) legend(off) graphregion(fcolor(white))


graph export "$output/Figure6A_high_son_preference.png", as(png) name("Graph") width(2400) replace



twoway (line hfls byear,lp(solid) lcolor(black)) (line lfls byear, lp(dash) lcolor(black)),xtitle("Birth year") ytitle("Cohort sex ratios") xlabel(1949(2)1965) ylabel(0.98(0.02)1.1) xline(1959, lp(dot) lcolor(red)) xline(1961, lp(dot) lcolor(red)) yline(0, lp(--) lcolor(black)) legend(off) graphregion(fcolor(white))

/*graph export "$output/f3_famine_lowson", as(png) name("Graph") width(2400) replace*/

graph export "$output/Figure6B_low_son_preference.png", as(png) name("Graph") width(2400) replace

restore


** Correlations *******
* Figure 5 & Figure A2 *
preserve
est clear

use  "$workdata/measures.dta",clear

twoway (lfitci sex82 sex53 , level(95) text(1.05 1.15 "Corr=0.66**")) (scatter sex82 sex53 [aweight=size53],msymbol(Oh)) , xtitle("Cohort sex ratios in 1953 Census") ytitle("Sex ratios in 1982 Census") legend(off) graphregion(fcolor(white)) 

graph export "$output/Figure5A_measure_1982.png", as(png) name("Graph") width(2400) replace



twoway (lfitci sex90 sex53 , level(95) text(1.05 1.15 "Corr=0.71***")) (scatter sex90 sex53 [aweight=size53],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("Sex ratios in 1990 Census") legend(off) graphregion(fcolor(white))

graph export "$output/Figure5B_measure_1990.png", as(png) name("Graph") width(2400) replace


twoway (lfitci last_sexratio sex53 , level(95) text(1.07 1.15 "Corr=0.66***")) (scatter last_sexratio sex53 [aweight=size53],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("Sex ratios of higher order birth") legend(off) graphregion(fcolor(white))

graph export "$output/Figure5C_measure_rule.png", as(png) name("Graph") width(2400) replace

twoway (lfitci shareb sex53 , level(95) text(1.3 1.2 "Corr=0.72***")) (scatter shareb sex53 [aweight=size],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("Fraction of boys among expected children") legend(off) graphregion(fcolor(white))


graph export "$output/Figure5D_measure_survey.png", as(png) name("Graph") width(2400) replace




twoway (lfitci gender_norm sex53 , level(95) text(1.2 1.2 "Corr=0.69***")) (scatter gender_norm sex53 [aweight=size],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("Attitudes about gender norm") legend(off) graphregion(fcolor(white))


graph export "$output/Figure5E_measure_CFPS.png", as(png) name("Graph") width(2400) replace





twoway (lfitci gdp sex53, level(95) text(10 1.15 "Corr=0.11")) (scatter gdp sex53 [aweight=size53],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("GDP") legend(off) graphregion(fcolor(white)) 

graph export "$output/FigureA1A_GDP.png", as(png) name("Graph") width(2400) replace



twoway (lfitci health sex53, level(95) text(1000 1.15 "Corr=0.28")) (scatter health sex53 [aweight=size53],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("Health facilities") legend(off) graphregion(fcolor(white)) 


graph export "$output/FigureA1B_health.png", as(png) name("Graph") width(2400) replace


twoway (lfitci studentshigher sex53, level(95) text(-1 1.15 "Corr=-0.13")) (scatter studentshigher sex53 [aweight=size53],msymbol(Oh)), xtitle("Cohort sex ratios in 1953 Census") ytitle("High school students") legend(off) graphregion(fcolor(white)) 

graph export "$output/FigureA1C_students.png", as(png) name("Graph") width(2400) replace


restore


**********************************
* Table A2: Regional correlation *

preserve
est clear

use "$workdata/measures.dta", clear
merge m:1 provcd using  "$rawdata/pre_famine_controls.dta"
tab _merge
drop if _merge==1 
drop if _merge==2
drop _merge

foreach var in healthinstitution doctors gdp revenue expenditure {
	replace `var'_mean=0 if `var'_mean==.
}



foreach var in healthinstitution doctors gdp revenue expenditure pop {
	reg `var'_mean sex53
	est store `var'
}

esttab healthinstitution doctors gdp revenue expenditure pop using "$output/TableA2_regional_correlation.csv",  replace b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)  r2 se

restore
